==> iam-1.100.0-sources.jar: software/amazon/awscdk/services/iam/GrantOnPrincipalAndResourceOptions.java <==
package software.amazon.awscdk.services.iam;

/**
 * (experimental) Options for a grant operation to both identity and resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:33:51.669Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.GrantOnPrincipalAndResourceOptions")
@software.amazon.jsii.Jsii.Proxy(GrantOnPrincipalAndResourceOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GrantOnPrincipalAndResourceOptions extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.iam.CommonGrantOptions {

    /**
     * (experimental) The resource with a resource policy.
     * <p>
     * The statement will always be added to the resource policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IResourceWithPolicy getResource();

    /**
     * (experimental) The principal to use in the statement for the resource policy.
     * <p>
     * Default: - the principal of the grantee will be used
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.IPrincipal getResourcePolicyPrincipal() {
        return null;
    }

    /**
     * (experimental) When referring to the resource in a resource policy, use this as ARN.
     * <p>
     * (Depending on the resource type, this needs to be '*' in a resource policy).
     * <p>
     * Default: Same as regular resource ARNs
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getResourceSelfArns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GrantOnPrincipalAndResourceOptions> {
        private software.amazon.awscdk.services.iam.IResourceWithPolicy resource;
        private software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal;
        private java.util.List<java.lang.String> resourceSelfArns;
        private java.util.List<java.lang.String> actions;
        private software.amazon.awscdk.services.iam.IGrantable grantee;
        private java.util.List<java.lang.String> resourceArns;

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResource}
         * @param resource The resource with a resource policy. This parameter is required.
         *                 The statement will always be added to the resource policy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder resource(software.amazon.awscdk.services.iam.IResourceWithPolicy resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourcePolicyPrincipal}
         * @param resourcePolicyPrincipal The principal to use in the statement for the resource policy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder resourcePolicyPrincipal(software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal) {
            this.resourcePolicyPrincipal = resourcePolicyPrincipal;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourceSelfArns}
         * @param resourceSelfArns When referring to the resource in a resource policy, use this as ARN.
         *                         (Depending on the resource type, this needs to be '*' in a resource policy).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder resourceSelfArns(java.util.List<java.lang.String> resourceSelfArns) {
            this.resourceSelfArns = resourceSelfArns;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getActions}
         * @param actions The actions to grant. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder actions(java.util.List<java.lang.String> actions) {
            this.actions = actions;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getGrantee}
         * @param grantee The principal to grant to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder grantee(software.amazon.awscdk.services.iam.IGrantable grantee) {
            this.grantee = grantee;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourceArns}
         * @param resourceArns The resource ARNs to grant to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder resourceArns(java.util.List<java.lang.String> resourceArns) {
            this.resourceArns = resourceArns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GrantOnPrincipalAndResourceOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GrantOnPrincipalAndResourceOptions build() {
            return new Jsii$Proxy(resource, resourcePolicyPrincipal, resourceSelfArns, actions, grantee, resourceArns);
        }
    }

    /**
     * An implementation for {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GrantOnPrincipalAndResourceOptions {
        private final software.amazon.awscdk.services.iam.IResourceWithPolicy resource;
        private final software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal;
        private final java.util.List<java.lang.String> resourceSelfArns;
        private final java.util.List<java.lang.String> actions;
        private final software.amazon.awscdk.services.iam.IGrantable grantee;
        private final java.util.List<java.lang.String> resourceArns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.resource = software.amazon.jsii.Kernel.get(this, "resource", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IResourceWithPolicy.class));
            this.resourcePolicyPrincipal = software.amazon.jsii.Kernel.get(this, "resourcePolicyPrincipal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IPrincipal.class));
            this.resourceSelfArns = software.amazon.jsii.Kernel.get(this, "resourceSelfArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.grantee = software.amazon.jsii.Kernel.get(this, "grantee", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IGrantable.class));
            this.resourceArns = software.amazon.jsii.Kernel.get(this, "resourceArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.iam.IResourceWithPolicy resource, final software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal, final java.util.List<java.lang.String> resourceSelfArns, final java.util.List<java.lang.String> actions, final software.amazon.awscdk.services.iam.IGrantable grantee, final java.util.List<java.lang.String> resourceArns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.resource = java.util.Objects.requireNonNull(resource, "resource is required");
            this.resourcePolicyPrincipal = resourcePolicyPrincipal;
            this.resourceSelfArns = resourceSelfArns;
            this.actions = java.util.Objects.requireNonNull(actions, "actions is required");
            this.grantee = java.util.Objects.requireNonNull(grantee, "grantee is required");
            this.resourceArns = java.util.Objects.requireNonNull(resourceArns, "resourceArns is required");
        }

        @Override
        public final software.amazon.awscdk.services.iam.IResourceWithPolicy getResource() {
            return this.resource;
        }

        @Override
        public final software.amazon.awscdk.services.iam.IPrincipal getResourcePolicyPrincipal() {
            return this.resourcePolicyPrincipal;
        }

        @Override
        public final java.util.List<java.lang.String> getResourceSelfArns() {
            return this.resourceSelfArns;
        }

        @Override
        public final java.util.List<java.lang.String> getActions() {
            return this.actions;
        }

        @Override
        public final software.amazon.awscdk.services.iam.IGrantable getGrantee() {
            return this.grantee;
        }

        @Override
        public final java.util.List<java.lang.String> getResourceArns() {
            return this.resourceArns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("resource", om.valueToTree(this.getResource()));
            if (this.getResourcePolicyPrincipal() != null) {
                data.set("resourcePolicyPrincipal", om.valueToTree(this.getResourcePolicyPrincipal()));
            }
            if (this.getResourceSelfArns() != null) {
                data.set("resourceSelfArns", om.valueToTree(this.getResourceSelfArns()));
            }
            data.set("actions", om.valueToTree(this.getActions()));
            data.set("grantee", om.valueToTree(this.getGrantee()));
            data.set("resourceArns", om.valueToTree(this.getResourceArns()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.GrantOnPrincipalAndResourceOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GrantOnPrincipalAndResourceOptions.Jsii$Proxy that = (GrantOnPrincipalAndResourceOptions.Jsii$Proxy) o;

            if (!resource.equals(that.resource)) return false;
            if (this.resourcePolicyPrincipal != null ? !this.resourcePolicyPrincipal.equals(that.resourcePolicyPrincipal) : that.resourcePolicyPrincipal != null) return false;
            if (this.resourceSelfArns != null ? !this.resourceSelfArns.equals(that.resourceSelfArns) : that.resourceSelfArns != null) return false;
            if (!actions.equals(that.actions)) return false;
            if (!grantee.equals(that.grantee)) return false;
            return this.resourceArns.equals(that.resourceArns);
        }

        @Override
        public final int hashCode() {
            int result = this.resource.hashCode();
            result = 31 * result + (this.resourcePolicyPrincipal != null ? this.resourcePolicyPrincipal.hashCode() : 0);
            result = 31 * result + (this.resourceSelfArns != null ? this.resourceSelfArns.hashCode() : 0);
            result = 31 * result + (this.actions.hashCode());
            result = 31 * result + (this.grantee.hashCode());
            result = 31 * result + (this.resourceArns.hashCode());
            return result;
        }
    }
}

==> iam-1.101.0-sources.jar: software/amazon/awscdk/services/iam/GrantOnPrincipalAndResourceOptions.java <==
package software.amazon.awscdk.services.iam;

/**
 * Options for a grant operation to both identity and resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:19.095Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.GrantOnPrincipalAndResourceOptions")
@software.amazon.jsii.Jsii.Proxy(GrantOnPrincipalAndResourceOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GrantOnPrincipalAndResourceOptions extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.iam.CommonGrantOptions {

    /**
     * The resource with a resource policy.
     * <p>
     * The statement will always be added to the resource policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IResourceWithPolicy getResource();

    /**
     * The principal to use in the statement for the resource policy.
     * <p>
     * Default: - the principal of the grantee will be used
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.IPrincipal getResourcePolicyPrincipal() {
        return null;
    }

    /**
     * When referring to the resource in a resource policy, use this as ARN.
     * <p>
     * (Depending on the resource type, this needs to be '*' in a resource policy).
     * <p>
     * Default: Same as regular resource ARNs
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getResourceSelfArns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GrantOnPrincipalAndResourceOptions> {
        private software.amazon.awscdk.services.iam.IResourceWithPolicy resource;
        private software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal;
        private java.util.List<java.lang.String> resourceSelfArns;
        private java.util.List<java.lang.String> actions;
        private software.amazon.awscdk.services.iam.IGrantable grantee;
        private java.util.List<java.lang.String> resourceArns;

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResource}
         * @param resource The resource with a resource policy. This parameter is required.
         *                 The statement will always be added to the resource policy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resource(software.amazon.awscdk.services.iam.IResourceWithPolicy resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourcePolicyPrincipal}
         * @param resourcePolicyPrincipal The principal to use in the statement for the resource policy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourcePolicyPrincipal(software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal) {
            this.resourcePolicyPrincipal = resourcePolicyPrincipal;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourceSelfArns}
         * @param resourceSelfArns When referring to the resource in a resource policy, use this as ARN.
         *                         (Depending on the resource type, this needs to be '*' in a resource policy).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceSelfArns(java.util.List<java.lang.String> resourceSelfArns) {
            this.resourceSelfArns = resourceSelfArns;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getActions}
         * @param actions The actions to grant. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actions(java.util.List<java.lang.String> actions) {
            this.actions = actions;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getGrantee}
         * @param grantee The principal to grant to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grantee(software.amazon.awscdk.services.iam.IGrantable grantee) {
            this.grantee = grantee;
            return this;
        }

        /**
         * Sets the value of {@link GrantOnPrincipalAndResourceOptions#getResourceArns}
         * @param resourceArns The resource ARNs to grant to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceArns(java.util.List<java.lang.String> resourceArns) {
            this.resourceArns = resourceArns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GrantOnPrincipalAndResourceOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GrantOnPrincipalAndResourceOptions build() {
            return new Jsii$Proxy(resource, resourcePolicyPrincipal, resourceSelfArns, actions, grantee, resourceArns);
        }
    }

    /**
     * An implementation for {@link GrantOnPrincipalAndResourceOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GrantOnPrincipalAndResourceOptions {
        private final software.amazon.awscdk.services.iam.IResourceWithPolicy resource;
        private final software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal;
        private final java.util.List<java.lang.String> resourceSelfArns;
        private final java.util.List<java.lang.String> actions;
        private final software.amazon.awscdk.services.iam.IGrantable grantee;
        private final java.util.List<java.lang.String> resourceArns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.resource = software.amazon.jsii.Kernel.get(this, "resource", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IResourceWithPolicy.class));
            this.resourcePolicyPrincipal = software.amazon.jsii.Kernel.get(this, "resourcePolicyPrincipal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IPrincipal.class));
            this.resourceSelfArns = software.amazon.jsii.Kernel.get(this, "resourceSelfArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.grantee = software.amazon.jsii.Kernel.get(this, "grantee", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IGrantable.class));
            this.resourceArns = software.amazon.jsii.Kernel.get(this, "resourceArns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.iam.IResourceWithPolicy resource, final software.amazon.awscdk.services.iam.IPrincipal resourcePolicyPrincipal, final java.util.List<java.lang.String> resourceSelfArns, final java.util.List<java.lang.String> actions, final software.amazon.awscdk.services.iam.IGrantable grantee, final java.util.List<java.lang.String> resourceArns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.resource = java.util.Objects.requireNonNull(resource, "resource is required");
            this.resourcePolicyPrincipal = resourcePolicyPrincipal;
            this.resourceSelfArns = resourceSelfArns;
            this.actions = java.util.Objects.requireNonNull(actions, "actions is required");
            this.grantee = java.util.Objects.requireNonNull(grantee, "grantee is required");
            this.resourceArns = java.util.Objects.requireNonNull(resourceArns, "resourceArns is required");
        }

        @Override
        public final software.amazon.awscdk.services.iam.IResourceWithPolicy getResource() {
            return this.resource;
        }

        @Override
        public final software.amazon.awscdk.services.iam.IPrincipal getResourcePolicyPrincipal() {
            return this.resourcePolicyPrincipal;
        }

        @Override
        public final java.util.List<java.lang.String> getResourceSelfArns() {
            return this.resourceSelfArns;
        }

        @Override
        public final java.util.List<java.lang.String> getActions() {
            return this.actions;
        }

        @Override
        public final software.amazon.awscdk.services.iam.IGrantable getGrantee() {
            return this.grantee;
        }

        @Override
        public final java.util.List<java.lang.String> getResourceArns() {
            return this.resourceArns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("resource", om.valueToTree(this.getResource()));
            if (this.getResourcePolicyPrincipal() != null) {
                data.set("resourcePolicyPrincipal", om.valueToTree(this.getResourcePolicyPrincipal()));
            }
            if (this.getResourceSelfArns() != null) {
                data.set("resourceSelfArns", om.valueToTree(this.getResourceSelfArns()));
            }
            data.set("actions", om.valueToTree(this.getActions()));
            data.set("grantee", om.valueToTree(this.getGrantee()));
            data.set("resourceArns", om.valueToTree(this.getResourceArns()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.GrantOnPrincipalAndResourceOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GrantOnPrincipalAndResourceOptions.Jsii$Proxy that = (GrantOnPrincipalAndResourceOptions.Jsii$Proxy) o;

            if (!resource.equals(that.resource)) return false;
            if (this.resourcePolicyPrincipal != null ? !this.resourcePolicyPrincipal.equals(that.resourcePolicyPrincipal) : that.resourcePolicyPrincipal != null) return false;
            if (this.resourceSelfArns != null ? !this.resourceSelfArns.equals(that.resourceSelfArns) : that.resourceSelfArns != null) return false;
            if (!actions.equals(that.actions)) return false;
            if (!grantee.equals(that.grantee)) return false;
            return this.resourceArns.equals(that.resourceArns);
        }

        @Override
        public final int hashCode() {
            int result = this.resource.hashCode();
            result = 31 * result + (this.resourcePolicyPrincipal != null ? this.resourcePolicyPrincipal.hashCode() : 0);
            result = 31 * result + (this.resourceSelfArns != null ? this.resourceSelfArns.hashCode() : 0);
            result = 31 * result + (this.actions.hashCode());
            result = 31 * result + (this.grantee.hashCode());
            result = 31 * result + (this.resourceArns.hashCode());
            return result;
        }
    }
}
